@@ -1,7 +1,7 @@
 package Perinci::Sub::GetArgs::Argv;
 
-our $DATE = '2016-10-27'; # DATE
-our $VERSION = '0.75'; # VERSION
+our $DATE = '2016-12-02'; # DATE
+our $VERSION = '0.76'; # VERSION
 
 use 5.010001;
 use strict;
@@ -940,7 +940,7 @@ sub get_args_from_argv {
         local $SIG{__WARN__} = sub{} if !$strict;
         my $old_go_conf = Getopt::Long::Configure(
             $strict ? "no_pass_through" : "pass_through",
-            "no_ignore_case", "permute", "bundling", "no_getopt_compat");
+            "no_ignore_case", "permute", "bundling", "no_getopt_compat", "gnu_compat");
         my $res = Getopt::Long::GetOptionsFromArray($argv, %$go_spec);
         Getopt::Long::Configure($old_go_conf);
         unless ($res) {
@@ -1102,7 +1102,7 @@ Perinci::Sub::GetArgs::Argv - Get subroutine arguments from command line argumen
 
 =head1 VERSION
 
-This document describes version 0.75 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2016-10-27.
+This document describes version 0.76 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2016-12-02.
 
 =head1 SYNOPSIS
 
@@ -1410,7 +1410,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-GetArgs-Argv>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-GetArgs-Argv>.
 
 =head1 BUGS
 
